@@ -1,7 +1,7 @@
 package Test::Perinci::Sub::Wrapper;
 
-our $DATE = '2015-02-10'; # DATE
-our $VERSION = '0.72'; # VERSION
+our $DATE = '2015-02-18'; # DATE
+our $VERSION = '0.73'; # VERSION
 
 use 5.010;
 use strict;
@@ -103,6 +103,18 @@ sub test_wrap {
                 diag "eval source: ", $eval_src
                     if $ENV{LOG_PERINCI_WRAPPER_CODE};
             } else {
+
+                # check that we don't generate comment after code (unless it
+                # uses '##' instead of '#'), because this makes cutting comments
+                # easier. XXX this is using a simple regex and misses some.
+                for my $line (split /^/, $wrap_res->[2]{source}) {
+                    if ($line =~ /(.*?)\s+#\s+(.*)/) {
+                        my ($before, $after) = ($1, $2);
+                        next unless $before =~ /\S/;
+                        ok 0; diag "Source code contains comment line after some code '$line' (if you do this, you must use ## instead of # to help ease removing comment lines (e.g. in Dist::Zilla::Plugin::Rinci::Wrap))";
+                    }
+                }
+
                 $sub = $wrap_res->[2]{sub};
             }
 
@@ -216,7 +228,7 @@ Test::Perinci::Sub::Wrapper - Provide test_wrap() to test wrapper
 
 =head1 VERSION
 
-This document describes version 0.72 of Test::Perinci::Sub::Wrapper (from Perl distribution Perinci-Sub-Wrapper), released on 2015-02-10.
+This document describes version 0.73 of Test::Perinci::Sub::Wrapper (from Perl distribution Perinci-Sub-Wrapper), released on 2015-02-18.
 
 =for Pod::Coverage test_wrap
 
